<p class="logo">
  <a href="{{ pathto(master_doc) }}">
    <img class="logo" src="{{ pathto('_static/bagou-sidebar.png', 1) }}" title="Bagou"/>
  </a>
</p>

<p>
  <iframe src="http://ghbtns.com/github-btn.html?user=toxinu&repo=django-bagou&type=watch&count=true&size=large"
    allowtransparency="true" frameborder="0" scrolling="0" width="200px" height="35px"></iframe>
</p>

<p>
  Requests is an elegant and simple HTTP library for Python, built for
  human beings.
</p>

<h3>Useful Links</h3>
<ul>
  <li><a href="http://github.com/toxinu/django-bagou">Bagou @ GitHub</a></li>
  <li><a href="http://pypi.python.org/pypi/django-bagou">Bagou @ PyPI</a></li>
  <li><a href="http://github.com/toxinu/django-bagou/issues">Issue Tracker</a></li>
</ul>
