<script type="text/javascript">
    var WEBSOCKET_URL = "{{ WEBSOCKET_URL }}";
</script>
<script src="{{ STATIC_URL|default:MEDIA_URL }}js/uuid.js"></script>
<script src="{{ STATIC_URL|default:MEDIA_URL }}js/bagou.js"></script>
